<?php
/**
 * Copyright (с) Cloud Linux GmbH & Cloud Linux Software, Inc 2010-2022 All Rights Reserved
 *
 * Licensed under CLOUD LINUX LICENSE AGREEMENT
 * https://www.
 * cloudlinux.
 * com/legal/
 */

namespace CloudLinux\SmartAdvice\App\Advice;

use CloudLinux\SmartAdvice\App\Model as BaseModel;

/**
 * Advice model
 */
class Model extends BaseModel {
	/**
	 * Advice ID.
	 *
	 * @var int
	 */
	public $id = 0;

	/**
	 * Advice type.
	 *
	 * @var string
	 */
	public $type = '';

	/**
	 * Advice status.
	 *
	 * @var string
	 */
	public $status = '';

	/**
	 * Advice short description.
	 *
	 * @var string
	 */
	public $description = '';

	/**
	 * Advice detail description.
	 *
	 * @var string
	 */
	public $detailed_description = '';

	/**
	 * Advice note.
	 *
	 * @var string
	 */
	public $note = '';

	/**
	 * Is premium.
	 *
	 * @var bool
	 */
	public $is_premium = false;

	/**
	 * Module name.
	 *
	 * @var string
	 */
	public $module_name = '';

	/**
	 * Requests.
	 *
	 * @var array
	 */
	public $requests = array();

	/**
	 * Advice total stages.
	 *
	 * @var int
	 */
	public $total_stages = 0;

	/**
	 * Advice completed stages.
	 *
	 * @var int
	 */
	public $completed_stages = 0;

	/**
	 * Subscription status.
	 *
	 * @var string
	 */
	public $subscription_status = '';

	/**
	 * Subscription upgrade url.
	 *
	 * @var string
	 */
	public $subscription_upgrade_url = '';

	/**
	 * Advice created at.
	 *
	 * @var string
	 */
	public $created_at = '';

	/**
	 * Advice updated at.
	 *
	 * @var string
	 */
	public $updated_at = '';

	/**
	 * Fill properties.
	 *
	 * @param array $data data.
	 *
	 * @return self
	 */
	public function fill( $data ) {
		if ( array_key_exists( 'subscription', $data ) ) {
			if ( array_key_exists( 'status', $data['subscription'] ) ) {
				$data['subscription_status'] = $data['subscription']['status'];
			}
			if ( array_key_exists( 'upgrade_url', $data['subscription'] ) ) {
				$data['subscription_upgrade_url'] = $data['subscription']['upgrade_url'];
			}
		}

		parent::fill( $data );

		return $this;
	}

	/**
	 * Is valid model.
	 *
	 * @return bool
	 */
	public function isValid() {
		return ! empty( $this->id ) && ! empty( $this->type ) && ! empty( $this->status );
	}

	/**
	 * To array.
	 *
	 * @return array
	 */
	public function toArray() {
		return array(
			'id'                       => $this->id,
			'type'                     => $this->type,
			'status'                   => $this->status,
			'description'              => $this->description,
			'detailed_description'     => $this->detailed_description,
			'note'                     => $this->note,
			'is_premium'               => $this->is_premium,
			'module_name'              => $this->module_name,
			'requests'                 => $this->requests,
			'total_stages'             => $this->total_stages,
			'completed_stages'         => $this->completed_stages,
			'subscription_status'      => $this->subscription_status,
			'subscription_upgrade_url' => $this->subscription_upgrade_url,
			'created_at'               => $this->created_at,
			'updated_at'               => $this->updated_at,
		);
	}

	/**
	 * Get stage percent.
	 *
	 * @return float
	 */
	public function stagePercent() {
		$total     = $this->total_stages;
		$completed = $this->completed_stages;

		if ( $total > 0 ) {
			return round( $completed / $total * 100 );
		}

		return 0;
	}

	/**
	 * Get spinner percent.
	 *
	 * @return string
	 */
	public function spinnerPercent() {
		$percent = $this->stagePercent();
		if ( $percent > 0 ) {
			return round( $percent / 10 ) . '0';
		}

		return '0';
	}

	/**
	 * Status for ui logic.
	 *
	 * @return string
	 */
	public function statusUi() {
		$status = $this->status;

		if ( 'pending' === $this->subscription_status ) {
			$status = $this->subscription_status;
		}

		return $status;
	}

	/**
	 * Need subscription.
	 *
	 * @return false|string
	 */
	public function needSubscription() {
		if ( 'no' === $this->subscription_status ) {
			return (string) $this->subscription_upgrade_url;
		}

		return false;
	}
}
